@@ -24,10 +24,19 @@ T = TypeVar("T")
 
 
 def run_async(obj, /):
-    if get_running_loop() is None:
+    try:
+        get_running_loop()
+        has_running_loop = True
+    except RuntimeError:
+        has_running_loop = False
+    if has_running_loop:
+        if isawaitable(obj):
+            return create_task(ensure_coroutine(obj))
+        return ensure_coroutine(obj)
+    elif isawaitable(obj):
         return run(ensure_coroutine(obj))
     else:
-        return create_task(ensure_coroutine(obj))
+        return obj
 
 
 @decorated
